using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace SharpCharts.Base.Data
{
    public class NestImportType : DefaultImportBase
    {
        public override BuiltDataType BuiltDataType
        {
            get { return Data.BuiltDataType.Minute; }
        }

        public override string DisplayName
        {
            get { return "Nest Data Import"; }
        }

        private int dataIndex;

        protected override bool? GetNextDataPoint()
        {
            if (base.Instrument == null)
                return false;

            if (base.data == null)
                return false;

            if (this.dataIndex >= base.data.Length - 1) //we skip the header
                return false;

            string[] quotes = base.data[this.data.Length - 1 - this.dataIndex++].Split(',');

            if (quotes.Length == 7)
            {
                double open, high, low, close;
                long volume, oi;
                DateTime date;

                if (!double.TryParse(quotes[2].Trim(), System.Globalization.NumberStyles.Any, System.Globalization.CultureInfo.InvariantCulture, out open))
                {
                    return false;
                }
                else
                {
                    base.Open = open;
                }

                if (!double.TryParse(quotes[3].Trim(), System.Globalization.NumberStyles.Any, System.Globalization.CultureInfo.InvariantCulture, out high))
                {
                    return false;
                }
                else
                {
                    base.High = high;
                }

                if (!double.TryParse(quotes[4].Trim(), System.Globalization.NumberStyles.Any, System.Globalization.CultureInfo.InvariantCulture, out low))
                {
                    return false;
                }
                else
                {
                    base.Low = low;
                }

                if (!double.TryParse(quotes[5].Trim(), System.Globalization.NumberStyles.Any, System.Globalization.CultureInfo.InvariantCulture, out close))
                {
                    return false;
                }
                else
                {
                    base.Close = close;
                }

                if (!DateTime.TryParseExact(quotes[1].Trim(), "dd-MM-yyyy HH:mm:ss", System.Globalization.CultureInfo.InvariantCulture, System.Globalization.DateTimeStyles.None, out date))
                {
                    return false;
                }
                else
                {
                    base.Time = date;
                }

                if (!long.TryParse(quotes[6].Trim(), System.Globalization.NumberStyles.Any, System.Globalization.CultureInfo.InvariantCulture, out volume))
                {
                    return false;
                }
                else
                {
                    base.Volume = volume;
                    if (volume == 0)
                    	return null;
                }

                base.OI = 0;

                return true;
            }
            else if (quotes.Length == 1) //empty rows. usually the last line of the file.
                return null;

            return false;
        }

    }
}
